/*
------------------------------------------------------------
	window.h - Generic Rendering Window
------------------------------------------------------------
 *  David Olofson, 2001
 * This code is released under the terms of the GPL.
 */

#ifndef _WINDOW_H_
#define _WINDOW_H_

#include "glSDL.h"

class gfxengine_t;

class window_t
{
	friend class gfxengine_t;
  public:
	window_t();
	virtual ~window_t();

	virtual void init(gfxengine_t *e);
	void place(int left = 0, int top = 0,
			int sizex = 200, int sizey = 200,
			int vsizex = -1, int vsizey = -1);
	void select();
	void invalidate(SDL_Rect *r = NULL);

	/* Rendering */
	Uint32 alloc_color(int r, int g, int b);
	void foreground(Uint32 color);
	void background(Uint32 color);

	void clear();
	void font(int fnt);
	void string(int x, int y, const char *txt);
	void center(int y, const char *txt);
	void string_fxp(int x, int y, const char *txt);
	void center_fxp(int y, const char *txt);
	int textwidth(const char *txt);

	void point(int x, int y);
	void rectangle(int x, int y, int w, int h);
	void fillrect(int x, int y, int w, int h);
	void fillrect_fxp(int x, int y, int w, int h);

	void sprite(int x, int y, int bank, int frame, int inval = 1);
	void sprite_fxp(int x, int y, int bank, int frame, int inval = 1);

	int x()		{ return rect.x / xsc; }
	int y()		{ return rect.y / ysc; }
	int width()	{ return rect.w / xsc; }
	int height()	{ return rect.h / ysc; }
	int x2()	{ return (rect.x + rect.w) / xsc; }
	int y2()	{ return (rect.y + rect.h) / ysc; }

  protected:
	/*
	 * Kludge: This is for window selection to work.
	 * the problem is that this will break (along
	 * with some other things) if more than one
	 * gfxengine_t instance is used.
	 */
	static window_t	*selected;	/* Selected */

	gfxengine_t	*engine;
	int		xsc, ysc;
	SDL_Rect	rect;
	int		vx, vy;
	int		gvx, gvy;
	int		__gvx, __gvy;
	int		vw, vh;
	Uint32		fgcolor, bgcolor;
	int		_font;
};

#endif
